Method: AbstractController::Base.supports_path?

Defined in:
lib/abstract_controller/base.rb

.supports_path?Boolean

Returns true if the given controller is capable of rendering a path. A subclass of AbstractController::Base may return false. An Email controller for example does not support paths, only full URLs.

Returns:

  • (Boolean)


191
192
193
# File 'lib/abstract_controller/base.rb', line 191

def self.supports_path?
  true
end