Method: AbstractController::Base#process

Defined in:
lib/abstract_controller/base.rb

#process(action) ⇒ Object

Calls the action going through the entire Action Dispatch stack.

The actual method that is called is determined by calling #method_for_action. If no method can handle the action, then an AbstractController::ActionNotFound error is raised.



145
146
147
148
149
150
151
152
153
154
155
# File 'lib/abstract_controller/base.rb', line 145

def process(action, ...)
  @_action_name = action.to_s

  unless action_name = _find_action_name(@_action_name)
    raise ActionNotFound.new("The action '#{action}' could not be found for #{self.class.name}", self, action)
  end

  @_response_body = nil

  process_action(action_name, ...)
end