Module: AbstractController::Callbacks
- Extended by:
- ActiveSupport::Concern
- Includes:
- ActiveSupport::Callbacks
- Included in:
- ActionController::Base, ActionController::ContentSecurityPolicy, ActionController::RequestForgeryProtection
- Defined in:
- lib/abstract_controller/callbacks.rb
Overview
Abstract Controller Callbacks
Abstract Controller provides hooks during the life cycle of a controller action. Callbacks allow you to trigger logic during this cycle. Available callbacks are:
after_actionappend_after_actionappend_around_actionappend_before_actionaround_actionbefore_actionprepend_after_actionprepend_around_actionprepend_before_actionskip_after_actionskip_around_actionskip_before_action
Defined Under Namespace
Modules: ClassMethods Classes: ActionFilter
Constant Summary collapse
- DEFAULT_INTERNAL_METHODS =
:nodoc:
[:_run_process_action_callbacks].freeze