Class: ActionController::CGIWrapper
- Defined in:
- lib/action_controller/rack_process.rb
Instance Attribute Summary collapse
-
#output_cookies ⇒ Object
readonly
Returns the value of attribute output_cookies.
Instance Method Summary collapse
-
#args ⇒ Object
Used to wrap the normal args variable used inside CGI.
- #cookies ⇒ Object
-
#env_table ⇒ Object
Used to wrap the normal env_table variable used inside CGI.
-
#initialize(request, *args) ⇒ CGIWrapper
constructor
A new instance of CGIWrapper.
- #params ⇒ Object
- #query_string ⇒ Object
-
#stdinput ⇒ Object
Used to wrap the normal stdinput variable used inside CGI.
Methods inherited from CGI
escapeHTML, escapeHTML_fail_on_nil
Methods included from ActionController::CgiExt::Stdinput
included, #initialize_with_stdinput
Constructor Details
#initialize(request, *args) ⇒ CGIWrapper
Returns a new instance of CGIWrapper.
262 263 264 265 266 267 268 |
# File 'lib/action_controller/rack_process.rb', line 262 def initialize(request, *args) @request = request @args = *args @input = request.body super *args end |
Instance Attribute Details
#output_cookies ⇒ Object (readonly)
Returns the value of attribute output_cookies.
260 261 262 |
# File 'lib/action_controller/rack_process.rb', line 260 def @output_cookies end |
Instance Method Details
#args ⇒ Object
Used to wrap the normal args variable used inside CGI.
283 284 285 |
# File 'lib/action_controller/rack_process.rb', line 283 def args @args end |
#cookies ⇒ Object
274 275 276 |
# File 'lib/action_controller/rack_process.rb', line 274 def @request. end |
#env_table ⇒ Object
Used to wrap the normal env_table variable used inside CGI.
288 289 290 |
# File 'lib/action_controller/rack_process.rb', line 288 def env_table @request.env end |
#params ⇒ Object
270 271 272 |
# File 'lib/action_controller/rack_process.rb', line 270 def params @params ||= @request.params end |
#query_string ⇒ Object
278 279 280 |
# File 'lib/action_controller/rack_process.rb', line 278 def query_string @request.query_string end |
#stdinput ⇒ Object
Used to wrap the normal stdinput variable used inside CGI.
293 294 295 |
# File 'lib/action_controller/rack_process.rb', line 293 def stdinput @input end |