Module: ActionController::ForceSSL
- Extended by:
- ActiveSupport::Concern
- Includes:
- AbstractController::Callbacks
- Defined in:
- lib/action_controller/metal/force_ssl.rb
Overview
This module provides a method which will redirect browser to use HTTPS protocol. This will ensure that user's sensitive information will be transferred safely over the internet. You should always force browser to use HTTPS when you're transferring sensitive information such as user authentication, account information, or credit card information.
Note that if you are really concerned about your application security,
you might consider using config.force_ssl in your config file instead.
That will ensure all the data transferred via HTTPS protocol and prevent
user from getting session hijacked when accessing the site under unsecured
HTTP protocol.
Defined Under Namespace
Modules: ClassMethods