Method: ActionController::Live::Buffer#ignore_disconnect

Defined in:
lib/action_controller/metal/live.rb

#ignore_disconnectObject

Ignore that the client has disconnected.

If this value is true, calling write after the client disconnects will result in the written content being silently discarded. If this value is false (the default), a ClientDisconnected exception will be raised.



206
207
208
# File 'lib/action_controller/metal/live.rb', line 206

def ignore_disconnect
  @ignore_disconnect
end