Method: ActionController::Renderers#render_to_body

Defined in:
lib/action_controller/metal/renderers.rb

#render_to_body(options) ⇒ Object

Called by render in AbstractController::Rendering which sets the return value as the response_body.

If no renderer is found, super returns control to ActionView::Rendering.render_to_body, if present.



141
142
143
# File 'lib/action_controller/metal/renderers.rb', line 141

def render_to_body(options)
  _render_to_body_with_renderer(options) || super
end