Module: ActionController::Rescue
- Extended by:
- ActiveSupport::Concern
- Includes:
- ActiveSupport::Rescuable
- Included in:
- Base
- Defined in:
- lib/action_controller/metal/rescue.rb
Overview
Action Controller Rescue
This module is responsible for providing rescue_from to controllers, wrapping actions to handle configured errors, and configuring when detailed exceptions must be shown.
Defined Under Namespace
Modules: ClassMethods
Instance Method Summary collapse
-
#show_detailed_exceptions? ⇒ Boolean
Override this method if you want to customize when detailed exceptions must be shown.
Instance Method Details
#show_detailed_exceptions? ⇒ Boolean
Override this method if you want to customize when detailed exceptions must be
shown. This method is only called when consider_all_requests_local is
false. By default, it returns false, but someone may set it to
request.local? so local requests in production still show the detailed
exception pages.
30 31 32 |
# File 'lib/action_controller/metal/rescue.rb', line 30 def show_detailed_exceptions? false end |