Method: ActionController::Verification::ClassMethods#verify

Defined in:
lib/action_controller/verification.rb

#verify(options = {}) ⇒ Object

Verify the given actions so that if certain prerequisites are not met, the user is redirected to a different action. The options parameter is a hash consisting of the following key/value pairs:

:params

a single key or an array of keys that must be in the params hash in order for the action(s) to be safely called.

:session

a single key or an array of keys that must be in the session in order for the action(s) to be safely called.

:flash

a single key or an array of keys that must be in the flash in order for the action(s) to be safely called.

:method

a single key or an array of keys–any one of which must match the current request method in order for the action(s) to be safely called. (The key should be a symbol: :get or :post, for example.)

:xhr

true/false option to ensure that the request is coming from an Ajax call or not.

:add_flash

a hash of name/value pairs that should be merged into the session’s flash if the prerequisites cannot be satisfied.

:add_headers

a hash of name/value pairs that should be merged into the response’s headers hash if the prerequisites cannot be satisfied.

:redirect_to

the redirection parameters to be used when redirecting if the prerequisites cannot be satisfied. You can redirect either to named route or to the action in some controller.

:render

the render parameters to be used when the prerequisites cannot be satisfied.

:only

only apply this verification to the actions specified in the associated array (may also be a single value).

:except

do not apply this verification to the actions specified in the associated array (may also be a single value).



81
82
83
84
85
# File 'lib/action_controller/verification.rb', line 81

def verify(options={})
  before_filter :only => options[:only], :except => options[:except] do |c|
    c.__send__ :verify_action, options
  end
end