Method: ActionDispatch::Request#request_id

Defined in:
lib/action_dispatch/http/request.rb

#request_idObject Also known as: uuid

Returns the unique request id, which is based on either the X-Request-Id header that can be generated by a firewall, load balancer, or web server, or by the RequestId middleware (which sets the action_dispatch.request_id environment variable).

This unique ID is useful for tracing a request from end-to-end as part of logging or debugging. This relies on the Rack variable set by the ActionDispatch::RequestId middleware.



336
337
338
# File 'lib/action_dispatch/http/request.rb', line 336

def request_id
  get_header ACTION_DISPATCH_REQUEST_ID
end