Method: ActionDispatch::Request#request_method
- Defined in:
- lib/action_dispatch/http/request.rb
#request_method ⇒ Object
Returns the HTTP method that the application should see. In the case where the method was overridden by a middleware (for instance, if a HEAD request was converted to a GET, or if a _method parameter was used to determine the method the application should use), this method returns the overridden value, not the original.
151 152 153 |
# File 'lib/action_dispatch/http/request.rb', line 151 def request_method @request_method ||= check_method(super) end |