Method: ActionDispatch::Routing::Mapper::Base#mount

Defined in:
lib/action_dispatch/routing/mapper.rb

#mount(app, options = nil) ⇒ Object

Mount a Rack-based application to be used within the application.

mount SomeRackApp, :at => "some_route"

Alternatively:

mount(SomeRackApp => "some_route")

All mounted applications come with routing helpers to access them. These are named after the class specified, so for the above example the helper is either some_rack_app_path or some_rack_app_url. To customize this helper’s name, use the :as option:

mount(SomeRackApp => "some_route", :as => "exciting")

This will generate the exciting_path and exciting_url helpers which can be used to navigate to this mounted app.



294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/action_dispatch/routing/mapper.rb', line 294

def mount(app, options = nil)
  if options
    path = options.delete(:at)
  else
    options = app
    app, path = options.find { |k, v| k.respond_to?(:call) }
    options.delete(app) if app
  end

  raise "A rack application must be specified" unless path

  match(path, options.merge(:to => app, :anchor => false, :format => false))
  self
end