Module: ActionDispatch::Routing::PolymorphicRoutes
- Included in:
- UrlFor
- Defined in:
- lib/action_dispatch/routing/polymorphic_routes.rb
Overview
Polymorphic URL helpers are methods for smart resolution to a named route call when given an Active Record model instance. They are to be used in combination with ActionController::Resources.
These methods are useful when you want to generate the correct URL or path to a RESTful resource without having to know the exact type of the record in question.
Nested resources and/or namespaces are also supported, as illustrated in the example:
polymorphic_url([:admin, @article, @comment])
results in:
admin_article_comment_url(@article, @comment)
Usage within the framework
Polymorphic URL helpers are used in a number of places throughout the Rails framework:
- url_for, so you can use it with a record as the argument, e.g. url_for(@article);
- ActionView::Helpers::FormHelper uses polymorphic_path, so you can write form_for(@article) without having to specify :url parameter for the form action;
- redirect_to (which, in fact, uses url_for) so you can write redirect_to(post) in your controllers;
- ActionView::Helpers::AtomFeedHelper, so you don't have to explicitly specify URLs for feed entries.
Prefixed polymorphic helpers
In addition to polymorphic_url and polymorphic_path methods, a number of prefixed helpers are available as a shorthand to action: "..." in options. Those are:
- edit_polymorphic_url, edit_polymorphic_path
- new_polymorphic_url, new_polymorphic_path
Example usage:
edit_polymorphic_path(@post) # => "/posts/1/edit"
polymorphic_path(@post, format: :pdf) # => "/posts/1.pdf"
Usage with mounted engines
If you are using a mounted engine and you need to use a polymorphic_url pointing at the engine's routes, pass in the engine's route proxy as the first argument to the method. For example:
polymorphic_url([blog, @post]) # calls blog.post_path(@post)
form_for([blog, @post]) # => "/blog/posts/1"
Defined Under Namespace
Classes: HelperMethodBuilder
Instance Method Summary collapse
-
#polymorphic_path(record_or_hash_or_array, options = {}) ⇒ Object
Returns the path component of a URL for the given record.
-
#polymorphic_url(record_or_hash_or_array, options = {}) ⇒ Object
Constructs a call to a named RESTful route for the given record and returns the resulting URL string.
Instance Method Details
#polymorphic_path(record_or_hash_or_array, options = {}) ⇒ Object
Returns the path component of a URL for the given record.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/action_dispatch/routing/polymorphic_routes.rb', line 124 def polymorphic_path(record_or_hash_or_array, = {}) if Hash === record_or_hash_or_array = record_or_hash_or_array.merge() record = .delete :id return polymorphic_path record, end if mapping = polymorphic_mapping(record_or_hash_or_array) return mapping.call(self, [record_or_hash_or_array, ], true) end opts = .dup action = opts.delete :action type = :path HelperMethodBuilder.polymorphic_method self, record_or_hash_or_array, action, type, opts end |
#polymorphic_url(record_or_hash_or_array, options = {}) ⇒ Object
Constructs a call to a named RESTful route for the given record and returns the resulting URL string. For example:
# calls post_url(post)
polymorphic_url(post) # => "http://example.com/posts/1"
polymorphic_url([blog, post]) # => "http://example.com/blogs/1/posts/1"
polymorphic_url([:admin, blog, post]) # => "http://example.com/admin/blogs/1/posts/1"
polymorphic_url([user, :blog, post]) # => "http://example.com/users/1/blog/posts/1"
polymorphic_url(Comment) # => "http://example.com/comments"
Options
- :action - Specifies the action prefix for the named route: :new or :edit. Default is no prefix.
- :routing_type - Allowed values are :path or :url. Default is :url.
Also includes all the options from url_for. These include such things as :anchor or :trailing_slash. Example usage is given below:
polymorphic_url([blog, post], anchor: 'my_anchor')
# => "http://example.com/blogs/1/posts/1#my_anchor"
polymorphic_url([blog, post], anchor: 'my_anchor', script_name: "/my_app")
# => "http://example.com/my_app/blogs/1/posts/1#my_anchor"
For all of these options, see the documentation for url_for.
Functionality
# an Article record
polymorphic_url(record) # same as article_url(record)
# a Comment record
polymorphic_url(record) # same as comment_url(record)
# it recognizes new records and maps to the collection
record = Comment.new
polymorphic_url(record) # same as comments_url()
# the class of a record will also map to the collection
polymorphic_url(Comment) # same as comments_url()
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/action_dispatch/routing/polymorphic_routes.rb', line 101 def polymorphic_url(record_or_hash_or_array, = {}) if Hash === record_or_hash_or_array = record_or_hash_or_array.merge() record = .delete :id return polymorphic_url record, end if mapping = polymorphic_mapping(record_or_hash_or_array) return mapping.call(self, [record_or_hash_or_array, ], false) end opts = .dup action = opts.delete :action type = opts.delete(:routing_type) || :url HelperMethodBuilder.polymorphic_method self, record_or_hash_or_array, action, type, opts end |