Class: ActionDispatch::Routing::RoutesInspector

Inherits:
Object
  • Object
show all
Defined in:
lib/action_dispatch/routing/inspector.rb

Overview

This class is just used for displaying route information when someone executes rails routes or looks at the RoutingError page. People should not use this class.

Instance Method Summary collapse

Constructor Details

#initialize(routes) ⇒ RoutesInspector

:nodoc:



59
60
61
62
# File 'lib/action_dispatch/routing/inspector.rb', line 59

def initialize(routes)
  @engines = {}
  @routes = routes
end

Instance Method Details

#format(formatter, filter = {}) ⇒ Object



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/action_dispatch/routing/inspector.rb', line 64

def format(formatter, filter = {})
  routes_to_display = filter_routes(normalize_filter(filter))
  routes = collect_routes(routes_to_display)
  if routes.none?
    formatter.no_routes(collect_routes(@routes), filter)
    return formatter.result
  end

  formatter.header routes
  formatter.section routes

  @engines.each do |name, engine_routes|
    formatter.section_title "Routes for #{name}"
    formatter.section engine_routes
  end

  formatter.result
end