Method: ActionView::Helpers::DateHelper#select_hour
- Defined in:
- lib/action_view/helpers/date_helper.rb
#select_hour(datetime, options = {}, html_options = {}) ⇒ Object
Returns a select tag with options for each of the hours 0 through 23 with the current hour selected. The hour can also be substituted for a hour number. Override the field name using the :field_name option, ‘hour’ by default.
Examples
my_time = Time.now + 6.hours
# Generates a select field for hours that defaults to the hour for the time in my_time
select_hour(my_time)
# Generates a select field for hours that defaults to the number given
select_hour(13)
# Generates a select field for hours that defaults to the minutes for the time in my_time
# that is named 'stride' rather than 'second'
select_hour(my_time, :field_name => 'stride')
# Generates a select field for hours with a custom prompt. Use :prompt => true for a
# generic prompt.
select_hour(13, :prompt =>'Choose hour')
479 480 481 |
# File 'lib/action_view/helpers/date_helper.rb', line 479 def select_hour(datetime, = {}, = {}) DateTimeSelector.new(datetime, , ).select_hour end |