Module: ActionView::Helpers::FormHelper
- Extended by:
- ActiveSupport::Concern
- Includes:
- FormTagHelper, UrlHelper
- Included in:
- ActionView::Helpers
- Defined in:
- lib/action_view/helpers/form_helper.rb
Overview
Form helpers are designed to make working with resources much easier compared to using vanilla HTML.
Forms for models are created with form_for. That method yields a form
builder that knows the model the form is about. The form builder is thus
able to generate default values for input fields that correspond to model
attributes, and also convenient names, IDs, endpoints, etc.
Conventions in the generated field names allow controllers to receive form
data nicely structured in params with no effort on your side.
For example, to create a new person you typically set up a new instance of
Person in the PeopleController#new action, @person, and
pass it to form_for:
<%= form_for @person do |f| %>
<%= f.label :first_name %>:
<%= f.text_field :first_name %><br />
<%= f.label :last_name %>:
<%= f.text_field :last_name %><br />
<%= f.submit %>
<% end %>
The HTML generated for this would be (modulus formatting):
Constant Summary
Constants included from TagHelper
TagHelper::BOOLEAN_ATTRIBUTES, TagHelper::PRE_CONTENT_STRINGS
Instance Method Summary collapse
-
#check_box(object_name, method, options = {}, checked_value = "1", unchecked_value = "0") ⇒ Object
Returns a checkbox tag tailored for accessing a specified attribute (identified by
method) on an object assigned to the template (identified byobject). -
#convert_to_model(object) ⇒ Object
Converts the given object to an ActiveModel compliant one.
-
#email_field(object_name, method, options = {}) ⇒ Object
Returns a text_field of type "email".
-
#fields_for(record_name, record_object = nil, options = {}, &block) ⇒ Object
Creates a scope around a specific model object like form_for, but doesn't create the form tags themselves.
-
#file_field(object_name, method, options = {}) ⇒ Object
Returns a file upload input tag tailored for accessing a specified attribute (identified by
method) on an object assigned to the template (identified byobject). -
#form_for(record, options = {}, &proc) ⇒ Object
Creates a form and a scope around a specific model object that is used as a base for questioning about values for the fields.
-
#hidden_field(object_name, method, options = {}) ⇒ Object
Returns a hidden input tag tailored for accessing a specified attribute (identified by
method) on an object assigned to the template (identified byobject). -
#label(object_name, method, content_or_options = nil, options = nil, &block) ⇒ Object
Returns a label tag tailored for labelling an input field for a specified attribute (identified by
method) on an object assigned to the template (identified byobject). -
#number_field(object_name, method, options = {}) ⇒ Object
Returns an input tag of type "number".
-
#password_field(object_name, method, options = {}) ⇒ Object
Returns an input tag of the "password" type tailored for accessing a specified attribute (identified by
method) on an object assigned to the template (identified byobject). -
#radio_button(object_name, method, tag_value, options = {}) ⇒ Object
Returns a radio button tag for accessing a specified attribute (identified by
method) on an object assigned to the template (identified byobject). -
#range_field(object_name, method, options = {}) ⇒ Object
Returns an input tag of type "range".
-
#search_field(object_name, method, options = {}) ⇒ Object
Returns an input of type "search" for accessing a specified attribute (identified by
method) on an object assigned to the template (identified byobject_name). -
#telephone_field(object_name, method, options = {}) ⇒ Object
(also: #phone_field)
Returns a text_field of type "tel".
-
#text_area(object_name, method, options = {}) ⇒ Object
Returns a textarea opening and closing tag set tailored for accessing a specified attribute (identified by
method) on an object assigned to the template (identified byobject). -
#text_field(object_name, method, options = {}) ⇒ Object
Returns an input tag of the "text" type tailored for accessing a specified attribute (identified by
method) on an object assigned to the template (identified byobject). -
#url_field(object_name, method, options = {}) ⇒ Object
Returns a text_field of type "url".
Methods included from UrlHelper
#_routes_context, #button_to, #current_page?, #link_to, #link_to_if, #link_to_unless, #link_to_unless_current, #mail_to, #url_for, #url_options
Methods included from TagHelper
#cdata_section, #content_tag, #escape_once, #tag
Methods included from CaptureHelper
#capture, #content_for, #content_for?, #flush_output_buffer, #provide, #with_output_buffer
Methods included from ActionDispatch::Routing::UrlFor
#initialize, #url_for, #url_options
Methods included from ActionDispatch::Routing::PolymorphicRoutes
#polymorphic_path, #polymorphic_url
Methods included from FormTagHelper
#button_tag, #check_box_tag, #email_field_tag, #field_set_tag, #file_field_tag, #form_tag, #hidden_field_tag, #image_submit_tag, #label_tag, #number_field_tag, #password_field_tag, #radio_button_tag, #range_field_tag, #search_field_tag, #select_tag, #submit_tag, #telephone_field_tag, #text_area_tag, #text_field_tag, #url_field_tag, #utf8_enforcer_tag
Methods included from TextHelper
#concat, #current_cycle, #cycle, #excerpt, #highlight, #pluralize, #reset_cycle, #safe_concat, #simple_format, #truncate, #word_wrap
Methods included from SanitizeHelper
#sanitize, #sanitize_css, #strip_links, #strip_tags
Instance Method Details
#check_box(object_name, method, options = {}, checked_value = "1", unchecked_value = "0") ⇒ Object
Returns a checkbox tag tailored for accessing a specified attribute (identified by method) on an object
assigned to the template (identified by object). This object must be an instance object (@object) and not a local object.
It's intended that method returns an integer and if that integer is above zero, then the checkbox is checked.
Additional options on the input tag can be passed as a hash with options. The checked_value defaults to 1
while the default unchecked_value is set to 0 which is convenient for boolean values.
Gotcha
The HTML specification says unchecked check boxes are not successful, and
thus web browsers do not send them. Unfortunately this introduces a gotcha:
if an Invoice model has a paid flag, and in the form that edits a paid
invoice the user unchecks its check box, no paid parameter is sent. So,
any mass-assignment idiom like
@invoice.update_attributes(params[:invoice])
wouldn't update the flag.
To prevent this the helper generates an auxiliary hidden field before the very check box. The hidden field has the same name and its attributes mimic an unchecked check box.
This way, the client either sends only the hidden field (representing the check box is unchecked), or both fields. Since the HTML specification says key/value pairs have to be sent in the same order they appear in the form, and parameters extraction gets the last occurrence of any repeated key in the query string, that works for ordinary forms.
Unfortunately that workaround does not work when the check box goes within an array-like parameter, as in
<%= fields_for "project[invoice_attributes][]", invoice, :index => nil do |form| %>
<%= form.check_box :paid %>
...
<% end %>
because parameter name repetition is precisely what Rails seeks to distinguish the elements of the array. For each item with a checked check box you get an extra ghost item with only that attribute, assigned to "0".
In that case it is preferable to either use check_box_tag or to use
hashes instead of arrays.
Examples
Let's say that @post.validated? is 1:
check_box("post", "validated")
# => <input name="post[validated]" type="hidden" value="0" />
# <input type="checkbox" id="post_validated" name="post[validated]" value="1" />
# Let's say that @puppy.gooddog is "no":
check_box("puppy", "gooddog", {}, "yes", "no")
# => <input name="puppy[gooddog]" type="hidden" value="no" />
# <input type="checkbox" id="puppy_gooddog" name="puppy[gooddog]" value="yes" />
check_box("eula", "accepted", { :class => 'eula_check' }, "yes", "no")
# => <input name="eula[accepted]" type="hidden" value="no" />
# <input type="checkbox" class="eula_check" id="eula_accepted" name="eula[accepted]" value="yes" />
840 841 842 |
# File 'lib/action_view/helpers/form_helper.rb', line 840 def check_box(object_name, method, = {}, checked_value = "1", unchecked_value = "0") InstanceTag.new(object_name, method, self, .delete(:object)).to_check_box_tag(, checked_value, unchecked_value) end |
#convert_to_model(object) ⇒ Object
Converts the given object to an ActiveModel compliant one.
108 109 110 |
# File 'lib/action_view/helpers/form_helper.rb', line 108 def convert_to_model(object) object.respond_to?(:to_model) ? object.to_model : object end |
#email_field(object_name, method, options = {}) ⇒ Object
Returns a text_field of type "email".
email_field("user", "address")
# => <input id="user_address" size="30" name="user[address]" type="email" />
929 930 931 |
# File 'lib/action_view/helpers/form_helper.rb', line 929 def email_field(object_name, method, = {}) InstanceTag.new(object_name, method, self, .delete(:object)).to_input_field_tag("email", ) end |
#fields_for(record_name, record_object = nil, options = {}, &block) ⇒ Object
Creates a scope around a specific model object like form_for, but doesn't create the form tags themselves. This makes fields_for suitable for specifying additional model objects in the same form.
Generic Examples
<%= form_for @person do |person_form| %>
First name: <%= person_form.text_field :first_name %>
Last name : <%= person_form.text_field :last_name %>
<%= fields_for @person. do || %>
Admin? : <%= permission_fields.check_box :admin %>
<% end %>
<%= f.submit %>
<% end %>
...or if you have an object that needs to be represented as a different parameter, like a Client that acts as a Person:
<%= fields_for :person, @client do |permission_fields| %>
Admin?: <%= .check_box :admin %>
<% end %>
...or if you don't have an object, just a name of the parameter:
<%= fields_for :person do |permission_fields| %>
Admin?: <%= .check_box :admin %>
<% end %>
Note: This also works for the methods in FormOptionHelper and DateHelper that are designed to work with an object as base, like FormOptionHelper#collection_select and DateHelper#datetime_select.
Nested Attributes Examples
When the object belonging to the current scope has a nested attribute writer for a certain attribute, fields_for will yield a new scope for that attribute. This allows you to create forms that set or change the attributes of a parent object and its associations in one go.
Nested attribute writers are normal setter methods named after an
association. The most common way of defining these writers is either
with accepts_nested_attributes_for in a model definition or by
defining a method with the proper name. For example: the attribute
writer for the association :address is called
address_attributes=.
Whether a one-to-one or one-to-many style form builder will be yielded depends on whether the normal reader method returns a single object or an array of objects.
One-to-one
Consider a Person class which returns a single Address from the address reader method and responds to the address_attributes= writer method:
class Person
def address
@address
end
def address_attributes=(attributes)
# Process the attributes hash
end
end
This model can now be used with a nested fields_for, like so:
<%= form_for @person do |person_form| %>
...
<%= person_form.fields_for :address do |address_fields| %>
Street : <%= address_fields.text_field :street %>
Zip code: <%= address_fields.text_field :zip_code %>
<% end %>
...
<% end %>
When address is already an association on a Person you can use
accepts_nested_attributes_for to define the writer method for you:
class Person < ActiveRecord::Base
has_one :address
accepts_nested_attributes_for :address
end
If you want to destroy the associated model through the form, you have
to enable it first using the :allow_destroy option for
accepts_nested_attributes_for:
class Person < ActiveRecord::Base
has_one :address
accepts_nested_attributes_for :address, :allow_destroy => true
end
Now, when you use a form element with the _destroy parameter,
with a value that evaluates to true, you will destroy the associated
model (eg. 1, '1', true, or 'true'):
<%= form_for @person do |person_form| %>
...
<%= person_form.fields_for :address do |address_fields| %>
...
Delete: <%= address_fields.check_box :_destroy %>
<% end %>
...
<% end %>
One-to-many
Consider a Person class which returns an array of Project instances from the projects reader method and responds to the projects_attributes= writer method:
class Person
def projects
[@project1, @project2]
end
def projects_attributes=(attributes)
# Process the attributes hash
end
end
Note that the projects_attributes= writer method is in fact required for fields_for to correctly identify :projects as a collection, and the correct indices to be set in the form markup.
When projects is already an association on Person you can use
accepts_nested_attributes_for to define the writer method for you:
class Person < ActiveRecord::Base
has_many :projects
accepts_nested_attributes_for :projects
end
This model can now be used with a nested fields_for. The block given to the nested fields_for call will be repeated for each instance in the collection:
<%= form_for @person do |person_form| %>
...
<%= person_form.fields_for :projects do |project_fields| %>
<% if project_fields.object.active? %>
Name: <%= project_fields.text_field :name %>
<% end %>
<% end %>
...
<% end %>
It's also possible to specify the instance to be used:
<%= form_for @person do |person_form| %>
...
<% @person.projects.each do |project| %>
<% if project.active? %>
<%= person_form.fields_for :projects, project do |project_fields| %>
Name: <%= project_fields.text_field :name %>
<% end %>
<% end %>
<% end %>
...
<% end %>
Or a collection to be used:
<%= form_for @person do |person_form| %>
...
<%= person_form.fields_for :projects, @active_projects do |project_fields| %>
Name: <%= project_fields.text_field :name %>
<% end %>
...
<% end %>
When projects is already an association on Person you can use
accepts_nested_attributes_for to define the writer method for you:
class Person < ActiveRecord::Base
has_many :projects
accepts_nested_attributes_for :projects
end
If you want to destroy any of the associated models through the
form, you have to enable it first using the :allow_destroy
option for accepts_nested_attributes_for:
class Person < ActiveRecord::Base
has_many :projects
accepts_nested_attributes_for :projects, :allow_destroy => true
end
This will allow you to specify which models to destroy in the
attributes hash by adding a form element for the _destroy
parameter with a value that evaluates to true
(eg. 1, '1', true, or 'true'):
<%= form_for @person do |person_form| %>
...
<%= person_form.fields_for :projects do |project_fields| %>
Delete: <%= project_fields.check_box :_destroy %>
<% end %>
...
<% end %>
604 605 606 607 608 609 |
# File 'lib/action_view/helpers/form_helper.rb', line 604 def fields_for(record_name, record_object = nil, = {}, &block) builder = instantiate_builder(record_name, record_object, , &block) output = capture(builder, &block) output.concat builder.hidden_field(:id) if output && [:hidden_field_id] && !builder.emitted_hidden_id? output end |
#file_field(object_name, method, options = {}) ⇒ Object
Returns a file upload input tag tailored for accessing a specified attribute (identified by method) on an object
assigned to the template (identified by object). Additional options on the input tag can be passed as a
hash with options. These options will be tagged onto the HTML as an HTML element attribute as in the example
shown.
Using this method inside a form_for block will set the enclosing form's encoding to multipart/form-data.
Examples
file_field(:user, :avatar)
=>
file_field(:post, :attached, :accept => 'text/html')
# => <input accept="text/html" type="file" id="post_attached" name="post[attached]" />
file_field(:attachment, :file, :class => 'file_input')
# => <input type="file" id="attachment_file" name="attachment[file]" class="file_input" />
750 751 752 |
# File 'lib/action_view/helpers/form_helper.rb', line 750 def file_field(object_name, method, = {}) InstanceTag.new(object_name, method, self, .delete(:object)).to_input_field_tag("file", .update({:size => nil})) end |
#form_for(record, options = {}, &proc) ⇒ Object
Creates a form and a scope around a specific model object that is used as a base for questioning about values for the fields.
Rails provides succinct resource-oriented form generation with form_for
like this:
<%= form_for @offer do |f| %>
<%= f.label :version, 'Version' %>:
<%= f.text_field :version %><br />
<%= f.label :author, 'Author' %>:
<%= f.text_field :author %><br />
<%= f.submit %>
<% end %>
There, form_for is able to generate the rest of RESTful form
parameters based on introspection on the record, but to understand what
it does we need to dig first into the alternative generic usage it is
based upon.
Generic form_for
The generic way to call form_for yields a form builder around a
model:
<%= form_for :person do |f| %>
First name: <%= f.text_field :first_name %><br />
Last name : <%= f.text_field :last_name %><br />
Biography : <%= f.text_area :biography %><br />
Admin? : <%= f.check_box :admin %><br />
<%= f.submit %>
<% end %>
There, the argument is a symbol or string with the name of the object the form is about.
The form builder acts as a regular form helper that somehow carries the model. Thus, the idea is that
<%= f.text_field :first_name %>
gets expanded to
<%= text_field :person, :first_name %>
The rightmost argument to form_for is an
optional hash of options:
- :url - The URL the form is submitted to. It takes the same
fields you pass to
url_fororlink_to. In particular you may pass here a named route directly as well. Defaults to the current action. - :namespace - A namespace for your form to ensure uniqueness of id attributes on form elements. The namespace attribute will be prefixed with underscore on the generated HTML id.
- :html - Optional HTML attributes for the form tag.
Also note that form_for doesn't create an exclusive scope. It's still
possible to use both the stand-alone FormHelper methods and methods
from FormTagHelper. For example:
<%= form_for @person do |f| %>
First name: <%= f.text_field :first_name %>
Last name : <%= f.text_field :last_name %>
Biography : <%= text_area :person, :biography %>
Admin? : <%= check_box_tag "person[admin]", @person.company.admin? %>
<%= f.submit %>
<% end %>
This also works for the methods in FormOptionHelper and DateHelper that are designed to work with an object as base, like FormOptionHelper#collection_select and DateHelper#datetime_select.
Resource-oriented style
As we said above, in addition to manually configuring the form_for
call, you can rely on automated resource identification, which will use
the conventions and named routes of that approach. This is the
preferred way to use form_for nowadays.
For example, if @post is an existing record you want to edit
<%= form_for @post do |f| %>
...
<% end %>
is equivalent to something like:
<%= form_for @post, :as => :post, :url => post_path(@post), :method => :put, :html => { :class => "edit_post", :id => "edit_post_45" } do |f| %>
...
<% end %>
And for new records
<%= form_for(Post.new) do |f| %>
...
<% end %>
is equivalent to something like:
<%= form_for @post, :as => :post, :url => posts_path, :html => { :class => "new_post", :id => "new_post" } do |f| %>
...
<% end %>
You can also overwrite the individual conventions, like this:
<%= form_for(@post, :url => super_posts_path) do |f| %>
...
<% end %>
You can also set the answer format, like this:
<%= form_for(@post, :format => :json) do |f| %>
...
<% end %>
If you have an object that needs to be represented as a different parameter, like a Person that acts as a Client:
<%= form_for(@person, :as => :client) do |f| %>
...
<% end %>
For namespaced routes, like admin_post_url:
<%= form_for([:admin, @post]) do |f| %>
...
<% end %>
If your resource has associations defined, for example, you want to add comments to the document given that the routes are set correctly:
<%= form_for([@document, @comment]) do |f| %>
...
<% end %>
Where @document = Document.find(params) and @comment = Comment.new.
Setting the method
You can force the form to use the full array of HTTP verbs by setting
:method => (:get|:post|:put|:delete)
in the options hash. If the verb is not GET or POST, which are natively supported by HTML forms, the form will be set to POST and a hidden input called _method will carry the intended verb for the server to interpret.
Unobtrusive JavaScript
Specifying:
:remote => true
in the options hash creates a form that will allow the unobtrusive JavaScript drivers to modify its behavior. The expected default behavior is an XMLHttpRequest in the background instead of the regular POST arrangement, but ultimately the behavior is the choice of the JavaScript driver implementor. Even though it's using JavaScript to serialize the form elements, the form submission will work just like a regular submission as viewed by the receiving side (all elements available in params).
Example:
<%= form_for(@post, :remote => true) do |f| %>
...
<% end %>
The HTML generated for this would be:
Removing hidden model id's
The form_for method automatically includes the model id as a hidden field in the form. This is used to maintain the correlation between the form data and its associated model. Some ORM systems do not use IDs on nested models so in this case you want to be able to disable the hidden id.
In the following example the Post model has many Comments stored within it in a NoSQL database, thus there is no primary key for comments.
Example:
<%= form_for(@post) do |f| %>
<% f.fields_for(:comments, :include_id => false) do |cf| %>
...
<% end %>
<% end %>
Customized form builders
You can also build forms using a customized FormBuilder class. Subclass FormBuilder and override or define some more helpers, then use your custom builder. For example, let's say you made a helper to automatically add labels to form inputs.
<%= form_for @person, :url => { :action => "create" }, :builder => LabellingFormBuilder do |f| %>
<%= f.text_field :first_name %>
<%= f.text_field :last_name %>
<%= f.text_area :biography %>
<%= f.check_box :admin %>
<%= f.submit %>
<% end %>
In this case, if you use this:
<%= render f %>
The rendered template is people/_labelling_form and the local variable referencing the form builder is called labelling_form.
The custom FormBuilder class is automatically merged with the options of a nested fields_for call, unless it's explicitly set.
In many cases you will want to wrap the above in another helper, so you could do something like the following:
def labelled_form_for(record_or_name_or_array, *args, &proc)
= args.
form_for(record_or_name_or_array, *(args << .merge(:builder => LabellingFormBuilder)), &proc)
end
If you don't need to attach a form to a model instance, then check out FormTagHelper#form_tag.
Form to external resources
When you build forms to external resources sometimes you need to set an authenticity token or just render a form without it, for example when you submit data to a payment gateway number and types of fields could be limited.
To set an authenticity token you need to pass an :authenticity_token parameter
<%= form_for @invoice, :url => external_url, :authenticity_token => 'external_token' do |f|
...
<% end %>
If you don't want to an authenticity token field be rendered at all just pass false:
<%= form_for @invoice, :url => external_url, :authenticity_token => false do |f|
...
<% end %>
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/action_view/helpers/form_helper.rb', line 357 def form_for(record, = {}, &proc) raise ArgumentError, "Missing block" unless block_given? [:html] ||= {} case record when String, Symbol object_name = record object = nil else object = record.is_a?(Array) ? record.last : record object_name = [:as] || ActiveModel::Naming.param_key(object) (record, ) end [:html][:remote] = .delete(:remote) if .has_key?(:remote) [:html][:method] = .delete(:method) if .has_key?(:method) [:html][:authenticity_token] = .delete(:authenticity_token) builder = [:parent_builder] = instantiate_builder(object_name, object, , &proc) fields_for = fields_for(object_name, object, , &proc) = builder.multipart? ? { :multipart => true } : {} output = form_tag(.delete(:url) || {}, .merge!(.delete(:html))) output << fields_for output.safe_concat('</form>') end |
#hidden_field(object_name, method, options = {}) ⇒ Object
Returns a hidden input tag tailored for accessing a specified attribute (identified by method) on an object
assigned to the template (identified by object). Additional options on the input tag can be passed as a
hash with options. These options will be tagged onto the HTML as an HTML element attribute as in the example
shown.
Examples
hidden_field(:signup, :pass_confirm)