Method: AbstractController::Base#available_action?
- Defined in:
- lib/abstract_controller/base.rb
#available_action?(action_name) ⇒ Boolean
Returns true if a method for the action is available and can be dispatched, false otherwise.
Notice that ‘action_methods.include?(“foo”)` may return false and `available_action?(“foo”)` returns true because this method considers actions that are also available through other means, for example, implicit render ones.
#### Parameters
-
action_name- The name of an action to be tested
178 179 180 |
# File 'lib/abstract_controller/base.rb', line 178 def available_action?(action_name) _find_action_name(action_name) end |