Module: AbstractController::Callbacks
- Extended by:
- ActiveSupport::Concern
- Includes:
- ActiveSupport::Callbacks
- Defined in:
- lib/abstract_controller/callbacks.rb
Overview
Abstract Controller Callbacks
Abstract Controller provides hooks during the life cycle of a controller action. Callbacks allow you to trigger logic during this cycle. Available callbacks are:
- after_action
- append_after_action
- append_around_action
- append_before_action
- around_action
- before_action
- prepend_after_action
- prepend_around_action
- prepend_before_action
- skip_after_action
- skip_around_action
- skip_before_action
NOTE: Calling the same callback multiple times will overwrite previous callback definitions.
Defined Under Namespace
Modules: ClassMethods Classes: ActionFilter