Method: ActionController::Parameters#deep_transform_keys
- Defined in:
- lib/action_controller/metal/strong_parameters.rb
#deep_transform_keys(&block) ⇒ Object
Returns a new ActionController::Parameters instance with the results of running block once for every key. This includes the keys from the root hash and from all nested hashes and arrays. The values are unchanged.
924 925 926 927 928 |
# File 'lib/action_controller/metal/strong_parameters.rb', line 924 def deep_transform_keys(&block) new_instance_with_inherited_permitted_status( _deep_transform_keys_in_object(@parameters, &block).to_unsafe_h ) end |