Method: ActionController::Parameters#each_value
- Defined in:
- lib/action_controller/metal/strong_parameters.rb
#each_value(&block) ⇒ Object
Convert all hashes in values into parameters, then yield each value in the same way as ‘Hash#each_value`.
414 415 416 417 418 419 420 421 |
# File 'lib/action_controller/metal/strong_parameters.rb', line 414 def each_value(&block) return to_enum(:each_value) unless block_given? @parameters.each_pair do |key, value| yield convert_hashes_to_parameters(key, value) end self end |