Method: ActionController::Parameters#stringify_keys
- Defined in:
- lib/action_controller/metal/strong_parameters.rb
#stringify_keys ⇒ Object
This is required by ActiveModel attribute assignment, so that user can pass Parameters to a mass assignment methods in a model. It should not matter as we are using HashWithIndifferentAccess internally.
1051 1052 1053 |
# File 'lib/action_controller/metal/strong_parameters.rb', line 1051 def stringify_keys # :nodoc: dup end |