Method: ActionController::Parameters#values_at
- Defined in:
- lib/action_controller/metal/strong_parameters.rb
#values_at(*keys) ⇒ Object
Returns values that were assigned to the given keys. Note that all the Hash objects will be converted to ActionController::Parameters.
1005 1006 1007 |
# File 'lib/action_controller/metal/strong_parameters.rb', line 1005 def values_at(*keys) convert_value_to_parameters(@parameters.values_at(*keys)) end |