Module: ActionController::HttpAuthentication::Basic

Extended by:
Basic
Included in:
Basic
Defined in:
lib/action_controller/http_authentication.rb

Overview

Makes it dead easy to do HTTP Basic authentication.

Simple Basic example:

class PostsController < ApplicationController
USER_NAME, PASSWORD = "dhh", "secret"

before_filter :authenticate, :except => [ :index ]

def index
  render :text => "Everyone can see me!"
end

def edit
  render :text => "I'm only accessible if you know the password"
end

private
  def authenticate
    authenticate_or_request_with_http_basic do |user_name, password|
      user_name == USER_NAME && password == PASSWORD
    end
  end
end

Here is a more advanced Basic example where only Atom feeds and the XML API is protected by HTTP authentication, the regular HTML interface is protected by a session approach:

class ApplicationController < ActionController::Base
before_filter :set_account, :authenticate

protected
  def 
    @account = Account.find_by_url_name(request.subdomains.first)
  end

  def authenticate
    case request.format
    when Mime::XML, Mime::ATOM
      if user = authenticate_with_http_basic { |u, p| @account.users.authenticate(u, p) }
        @current_user = user
      else
        request_http_basic_authentication
      end
    else
      if session_authenticated?
        @current_user = @account.users.find(session[:authenticated][:user_id])
      else
        redirect_to() and return false
      end
    end
  end
end

In your integration tests, you can do something like this:

def test_access_granted_from_xml
get(
  "/notes/1.xml", nil,
  :authorization => ActionController::HttpAuthentication::Basic.encode_credentials(users(:dhh).name, users(:dhh).password)
)

assert_equal 200, status
end

Simple Digest example:

require 'digest/md5'
class PostsController < ApplicationController
REALM = "SuperSecret"
USERS = {"dhh" => "secret", #plain text password
         "dap" => Digest:MD5::hexdigest(["dap",REALM,"secret"].join(":"))  #ha1 digest password

before_filter :authenticate, :except => [:index]

def index
  render :text => "Everyone can see me!"
end

def edit
  render :text => "I'm only accessible if you know the password"
end

private
  def authenticate
    authenticate_or_request_with_http_digest(REALM) do |username|
      USERS[username]
    end
  end
end

NOTE: The authenticate_or_request_with_http_digest block must return the user's password or the ha1 digest hash so the framework can appropriately hash to check the user's credentials. Returning nil will cause authentication to fail. Storing the ha1 hash: MD5(username:realm:password), is better than storing a plain password. If the password file or database is compromised, the attacker would be able to use the ha1 hash to authenticate as the user at this realm, but would not have the user's password to try using at other sites.

On shared hosts, Apache sometimes doesn't pass authentication headers to FCGI instances. If your environment matches this description and you cannot authenticate, try this rule in your Apache setup:

RewriteRule ^(.*)$ dispatch.fcgi [E=X-HTTP_AUTHORIZATION:%{HTTP:Authorization},QSA,L]

Defined Under Namespace

Modules: ControllerMethods

Instance Method Summary collapse

Instance Method Details

#authenticate(controller, &login_procedure) ⇒ Object



124
125
126
127
128
# File 'lib/action_controller/http_authentication.rb', line 124

def authenticate(controller, &)
  unless authorization(controller.request).blank?
    .call(*user_name_and_password(controller.request))
  end
end

#authentication_request(controller, realm) ⇒ Object



149
150
151
152
# File 'lib/action_controller/http_authentication.rb', line 149

def authentication_request(controller, realm)
  controller.headers["WWW-Authenticate"] = %(Basic realm="#{realm.gsub(/"/, "")}")
  controller.__send__ :render, :text => "HTTP Basic: Access denied.\n", :status => :unauthorized
end

#authorization(request) ⇒ Object



134
135
136
137
138
139
# File 'lib/action_controller/http_authentication.rb', line 134

def authorization(request)
  request.env['HTTP_AUTHORIZATION']   ||
  request.env['X-HTTP_AUTHORIZATION'] ||
  request.env['X_HTTP_AUTHORIZATION'] ||
  request.env['REDIRECT_X_HTTP_AUTHORIZATION']
end

#decode_credentials(request) ⇒ Object



141
142
143
# File 'lib/action_controller/http_authentication.rb', line 141

def decode_credentials(request)
  ActiveSupport::Base64.decode64(authorization(request).split(' ', 2).last || '')
end

#encode_credentials(user_name, password) ⇒ Object



145
146
147
# File 'lib/action_controller/http_authentication.rb', line 145

def encode_credentials(user_name, password)
  "Basic #{ActiveSupport::Base64.encode64("#{user_name}:#{password}")}"
end

#user_name_and_password(request) ⇒ Object



130
131
132
# File 'lib/action_controller/http_authentication.rb', line 130

def user_name_and_password(request)
  decode_credentials(request).split(/:/, 2)
end