Module: ActionController::HttpAuthentication::Token

Extended by:
Token
Included in:
Token
Defined in:
lib/action_controller/metal/http_authentication.rb

Overview

Makes it dead easy to do HTTP Token authentication.

Simple Token example:

class PostsController < ApplicationController
TOKEN = "secret"

before_action :authenticate, except: [ :index ]

def index
  render text: "Everyone can see me!"
end

def edit
  render text: "I'm only accessible if you know the password"
end

private
  def authenticate
    authenticate_or_request_with_http_token do |token, options|
      token == TOKEN
    end
  end
end

Here is a more advanced Token example where only Atom feeds and the XML API is protected by HTTP token authentication, the regular HTML interface is protected by a session approach:

class ApplicationController < ActionController::Base
before_action :set_account, :authenticate

protected
  def 
    @account = Account.find_by(url_name: request.subdomains.first)
  end

  def authenticate
    case request.format
    when Mime::XML, Mime::ATOM
      if user = authenticate_with_http_token { |t, o| @account.users.authenticate(t, o) }
        @current_user = user
      else
        request_http_token_authentication
      end
    else
      if session_authenticated?
        @current_user = @account.users.find(session[:authenticated][:user_id])
      else
        redirect_to() and return false
      end
    end
  end
end

In your integration tests, you can do something like this:

def test_access_granted_from_xml
get(
  "/notes/1.xml", nil,
  'HTTP_AUTHORIZATION' => ActionController::HttpAuthentication::Token.encode_credentials(users(:dhh).token)
)

assert_equal 200, status
end

On shared hosts, Apache sometimes doesn't pass authentication headers to FCGI instances. If your environment matches this description and you cannot authenticate, try this rule in your Apache setup:

RewriteRule ^(.*)$ dispatch.fcgi [E=X-HTTP_AUTHORIZATION:%{HTTP:Authorization},QSA,L]

Defined Under Namespace

Modules: ControllerMethods

Constant Summary collapse

TOKEN_REGEX =
/^Token /
AUTHN_PAIR_DELIMITERS =
/(?:,|;|\t+)/

Instance Method Summary collapse

Instance Method Details

#authenticate(controller, &login_procedure) ⇒ Object

If token Authorization header is present, call the login procedure with the present token and options.

[controller] ActionController::Base instance for the current request.

[login_procedure] Proc to call if a token is present. The Proc should take two arguments:

authenticate(controller) { |token, options| ... }

Returns the return value of login_procedure if a token is found. Returns nil if no token is found.



420
421
422
423
424
425
# File 'lib/action_controller/metal/http_authentication.rb', line 420

def authenticate(controller, &)
  token, options = token_and_options(controller.request)
  unless token.blank?
    .call(token, options)
  end
end

#authentication_request(controller, realm) ⇒ Object

Sets a WWW-Authenticate to let the client know a token is desired.

controller - ActionController::Base instance for the outgoing response. realm - String realm to use in the header.

Returns nothing.



484
485
486
487
# File 'lib/action_controller/metal/http_authentication.rb', line 484

def authentication_request(controller, realm)
  controller.headers["WWW-Authenticate"] = %(Token realm="#{realm.gsub(/"/, "")}")
  controller.__send__ :render, :text => "HTTP Token: Access denied.\n", :status => :unauthorized
end

#encode_credentials(token, options = {}) ⇒ Object

Encodes the given token and options into an Authorization header value.

token - String token. options - optional Hash of the options.

Returns String.



471
472
473
474
475
476
# File 'lib/action_controller/metal/http_authentication.rb', line 471

def encode_credentials(token, options = {})
  values = ["token=#{token.to_s.inspect}"] + options.map do |key, value|
    "#{key}=#{value.to_s.inspect}"
  end
  "Token #{values * ", "}"
end

#params_array_from(raw_params) ⇒ Object

Takes raw_params and turns it into an array of parameters



449
450
451
# File 'lib/action_controller/metal/http_authentication.rb', line 449

def params_array_from(raw_params)
  raw_params.map { |param| param.split %r/=(.+)?/ }
end

#raw_params(auth) ⇒ Object

This method takes an authorization body and splits up the key-value pairs by the standardized :, ;, or \t delimiters defined in AUTHN_PAIR_DELIMITERS.



461
462
463
# File 'lib/action_controller/metal/http_authentication.rb', line 461

def raw_params(auth)
  auth.sub(TOKEN_REGEX, '').split(/"\s*#{AUTHN_PAIR_DELIMITERS}\s*/)
end

#rewrite_param_values(array_params) ⇒ Object

This removes the " characters wrapping the value.



454
455
456
# File 'lib/action_controller/metal/http_authentication.rb', line 454

def rewrite_param_values(array_params)
  array_params.each { |param| param.last.gsub! %r/^"|"$/, '' }
end

#token_and_options(request) ⇒ Object

Parses the token and options out of the token authorization header. If the header looks like this: Authorization: Token token="abc", nonce="def" Then the returned token is "abc", and the options is "def"

request - ActionDispatch::Request instance with the current headers.

Returns an Array of [String, Hash] if a token is present. Returns nil if no token is found.



436
437
438
439
440
441
442
# File 'lib/action_controller/metal/http_authentication.rb', line 436

def token_and_options(request)
  authorization_request = request.authorization.to_s
  if authorization_request[TOKEN_REGEX]
    params = token_params_from authorization_request
    [params.shift.last, Hash[params].with_indifferent_access]
  end
end

#token_params_from(auth) ⇒ Object



444
445
446
# File 'lib/action_controller/metal/http_authentication.rb', line 444

def token_params_from(auth)
  rewrite_param_values params_array_from raw_params auth
end