Module: ActionController::HttpAuthentication::Token

Extended by:
Token
Included in:
Token
Defined in:
lib/action_controller/metal/http_authentication.rb

Overview

Makes it dead easy to do HTTP Token authentication.

Simple Token example:

class PostsController < ApplicationController
TOKEN = "secret"

before_filter :authenticate, :except => [ :index ]

def index
  render :text => "Everyone can see me!"
end

def edit
  render :text => "I'm only accessible if you know the password"
end

private
  def authenticate
    authenticate_or_request_with_http_token do |token, options|
      token == TOKEN
    end
  end
end

Here is a more advanced Token example where only Atom feeds and the XML API is protected by HTTP token authentication, the regular HTML interface is protected by a session approach:

class ApplicationController < ActionController::Base
before_filter :set_account, :authenticate

protected
  def 
    @account = .find_by_url_name(request.subdomains.first)
  end

  def authenticate
    case request.format
    when Mime::XML, Mime::ATOM
      if user = authenticate_with_http_token { |t, o| @account.users.authenticate(t, o) }
        @current_user = user
      else
        request_http_token_authentication
      end
    else
      if session_authenticated?
        @current_user = @account.users.find(session[:authenticated][:user_id])
      else
        redirect_to() and return false
      end
    end
  end
end

In your integration tests, you can do something like this:

def test_access_granted_from_xml
get(
  "/notes/1.xml", nil,
  :authorization => ActionController::HttpAuthentication::Token.encode_credentials(users(:dhh).token)
)

assert_equal 200, status
end

On shared hosts, Apache sometimes doesn't pass authentication headers to FCGI instances. If your environment matches this description and you cannot authenticate, try this rule in your Apache setup:

RewriteRule ^(.*)$ dispatch.fcgi [E=X-HTTP_AUTHORIZATION:%{HTTP:Authorization},QSA,L]

Defined Under Namespace

Modules: ControllerMethods

Instance Method Summary collapse

Instance Method Details

#authenticate(controller, &login_procedure) ⇒ Object

If token Authorization header is present, call the login procedure with the present token and options.

controller - ActionController::Base instance for the current request. login_procedure - Proc to call if a token is present. The Proc should take 2 arguments: authenticate(controller) { |token, options| ... }

Returns the return value of &login_procedure if a token is found. Returns nil if no token is found.



409
410
411
412
413
414
# File 'lib/action_controller/metal/http_authentication.rb', line 409

def authenticate(controller, &)
  token, options = token_and_options(controller.request)
  unless token.blank?
    .call(token, options)
  end
end

#authentication_request(controller, realm) ⇒ Object

Sets a WWW-Authenticate to let the client know a token is desired.

controller - ActionController::Base instance for the outgoing response. realm - String realm to use in the header.

Returns nothing.



457
458
459
460
# File 'lib/action_controller/metal/http_authentication.rb', line 457

def authentication_request(controller, realm)
  controller.headers["WWW-Authenticate"] = %(Token realm="#{realm.gsub(/"/, "")}")
  controller.__send__ :render, :text => "HTTP Token: Access denied.\n", :status => :unauthorized
end

#encode_credentials(token, options = {}) ⇒ Object

Encodes the given token and options into an Authorization header value.

token - String token. options - optional Hash of the options.

Returns String.



444
445
446
447
448
449
# File 'lib/action_controller/metal/http_authentication.rb', line 444

def encode_credentials(token, options = {})
  values = ["token=#{token.to_s.inspect}"] + options.map do |key, value|
    "#{key}=#{value.to_s.inspect}"
  end
  "Token #{values * ", "}"
end

#token_and_options(request) ⇒ Object

Parses the token and options out of the token authorization header. If the header looks like this: Authorization: Token token="abc", nonce="def" Then the returned token is "abc", and the options is => "def"

request - ActionDispatch::Request instance with the current headers.

Returns an Array of [String, Hash] if a token is present. Returns nil if no token is found.



425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/action_controller/metal/http_authentication.rb', line 425

def token_and_options(request)
  if header = request.authorization.to_s[/^Token (.*)/]
    values = Hash[$1.split(',').map do |value|
      value.strip!                      # remove any spaces between commas and values
      key, value = value.split(/\=\"?/) # split key=value pairs
      value.chomp!('"')                 # chomp trailing " in value
      value.gsub!(/\\\"/, '"')          # unescape remaining quotes
      [key, value]
    end]
    [values.delete("token"), values.with_indifferent_access]
  end
end