Method: ActionDispatch::Request#authorization
- Defined in:
- lib/action_dispatch/http/request.rb
#authorization ⇒ Object
Returns the authorization header regardless of whether it was specified directly or through one of the proxy alternatives.
465 466 467 468 469 470 |
# File 'lib/action_dispatch/http/request.rb', line 465 def get_header("HTTP_AUTHORIZATION") || get_header("X-HTTP_AUTHORIZATION") || get_header("X_HTTP_AUTHORIZATION") || get_header("REDIRECT_X_HTTP_AUTHORIZATION") end |