Method: ActionDispatch::Request#form_data?
- Defined in:
- lib/action_dispatch/http/request.rb
#form_data? ⇒ Boolean
Determine whether the request body contains form-data by checking the request Content-Type for one of the media-types: application/x-www-form-urlencoded or multipart/form-data. The list of form-data media types can be modified through the FORM_DATA_MEDIA_TYPES array.
A request body is not assumed to contain form-data when no Content-Type header is provided and the request_method is POST.
378 379 380 |
# File 'lib/action_dispatch/http/request.rb', line 378 def form_data? FORM_DATA_MEDIA_TYPES.include?(media_type) end |