Method: ActionDispatch::Request#send_early_hints
- Defined in:
- lib/action_dispatch/http/request.rb
#send_early_hints(links) ⇒ Object
Early Hints is an HTTP/2 status code that indicates hints to help a client start making preparations for processing the final response.
If the env contains rack.early_hints then the server accepts HTTP2 push for link headers.
The send_early_hints method accepts a hash of links as follows:
send_early_hints("link" => "</style.css>; rel=preload; as=style,</script.js>; rel=preload")
If you are using javascript_include_tag or stylesheet_link_tag the Early Hints headers are included by default if supported.
254 255 256 |
# File 'lib/action_dispatch/http/request.rb', line 254 def send_early_hints(links) env["rack.early_hints"]&.call(links) end |