Method: ActionDispatch::Routing::PolymorphicRoutes#polymorphic_url
- Defined in:
- lib/action_dispatch/routing/polymorphic_routes.rb
#polymorphic_url(record_or_hash_or_array, options = {}) ⇒ Object
Constructs a call to a named RESTful route for the given record and returns the resulting URL string. For example:
# calls post_url(post)
polymorphic_url(post) # => "http://example.com/posts/1"
polymorphic_url([blog, post]) # => "http://example.com/blogs/1/posts/1"
polymorphic_url([:admin, blog, post]) # => "http://example.com/admin/blogs/1/posts/1"
polymorphic_url([user, :blog, post]) # => "http://example.com/users/1/blog/posts/1"
polymorphic_url(Comment) # => "http://example.com/comments"
Options
-
:action- Specifies the action prefix for the named route::newor:edit. Default is no prefix. -
:routing_type- Allowed values are:pathor:url. Default is:url.
Examples
# an Article record
polymorphic_url(record) # same as article_url(record)
# a Comment record
polymorphic_url(record) # same as comment_url(record)
# it recognizes new records and maps to the collection
record = Comment.new
polymorphic_url(record) # same as comments_url()
# the class of a record will also map to the collection
polymorphic_url(Comment) # same as comments_url()
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/action_dispatch/routing/polymorphic_routes.rb', line 78 def polymorphic_url(record_or_hash_or_array, = {}) if record_or_hash_or_array.kind_of?(Array) record_or_hash_or_array = record_or_hash_or_array.compact record_or_hash_or_array = record_or_hash_or_array[0] if record_or_hash_or_array.size == 1 end record = extract_record(record_or_hash_or_array) record = record.to_model if record.respond_to?(:to_model) args = case record_or_hash_or_array when Hash; [ record_or_hash_or_array ] when Array; record_or_hash_or_array.dup else [ record_or_hash_or_array ] end inflection = if [:action].to_s == "new" args.pop :singular elsif (record.respond_to?(:persisted?) && !record.persisted?) args.pop :plural elsif record.is_a?(Class) args.pop :plural else :singular end args.delete_if {|arg| arg.is_a?(Symbol) || arg.is_a?(String)} named_route = build_named_route_call(record_or_hash_or_array, inflection, ) = .except(:action, :routing_type) unless .empty? args.last.kind_of?(Hash) ? args.last.merge!() : args << end send(named_route, *args) end |