Module: ActionDispatch::Http::Cache::Response
- Included in:
- Response
- Defined in:
- lib/action_dispatch/http/cache.rb
Instance Attribute Summary collapse
-
#cache_control ⇒ Object
readonly
Returns the value of attribute cache_control.
Instance Method Summary collapse
- #date ⇒ Object
- #date=(utc_time) ⇒ Object
- #date? ⇒ Boolean
-
#etag=(weak_validators) ⇒ Object
This method sets a weak ETag validator on the response so browsers and proxies may cache the response, keyed on the ETag.
- #etag? ⇒ Boolean
- #last_modified ⇒ Object
- #last_modified=(utc_time) ⇒ Object
- #last_modified? ⇒ Boolean
- #strong_etag=(strong_validators) ⇒ Object
-
#strong_etag? ⇒ Boolean
True if an ETag is set, and it isn't a weak validator (not preceded with
W/). - #weak_etag=(weak_validators) ⇒ Object
-
#weak_etag? ⇒ Boolean
True if an ETag is set, and it's a weak validator (preceded with
W/).
Instance Attribute Details
#cache_control ⇒ Object (readonly)
Returns the value of attribute cache_control.
181 182 183 |
# File 'lib/action_dispatch/http/cache.rb', line 181 def cache_control @cache_control end |
Instance Method Details
#date ⇒ Object
197 198 199 200 201 |
# File 'lib/action_dispatch/http/cache.rb', line 197 def date if date_header = get_header(DATE) Time.httpdate(date_header) end end |
#date=(utc_time) ⇒ Object
207 208 209 |
# File 'lib/action_dispatch/http/cache.rb', line 207 def date=(utc_time) set_header DATE, utc_time.httpdate end |
#date? ⇒ Boolean
203 204 205 |
# File 'lib/action_dispatch/http/cache.rb', line 203 def date? has_header? DATE end |
#etag=(weak_validators) ⇒ Object
This method sets a weak ETag validator on the response so browsers and proxies
may cache the response, keyed on the ETag. On subsequent requests, the
If-None-Match header is set to the cached ETag. If it matches the current
ETag, we can return a 304 Not Modified response with no body, letting the
browser or proxy know that their cache is current. Big savings in request time
and network bandwidth.
Weak ETags are considered to be semantically equivalent but not byte-for-byte identical. This is perfect for browser caching of HTML pages where we don't care about exact equality, just what the user is viewing.
Strong ETags are considered byte-for-byte identical. They allow a browser or
proxy cache to support Range requests, useful for paging through a PDF file
or scrubbing through a video. Some CDNs only support strong ETags and will
ignore weak ETags entirely.
Weak ETags are what we almost always need, so they're the default. Check out #strong_etag= to provide a strong ETag validator.
229 230 231 |
# File 'lib/action_dispatch/http/cache.rb', line 229 def etag=(weak_validators) self.weak_etag = weak_validators end |
#etag? ⇒ Boolean
241 |
# File 'lib/action_dispatch/http/cache.rb', line 241 def etag?; etag; end |
#last_modified ⇒ Object
183 184 185 186 187 |
# File 'lib/action_dispatch/http/cache.rb', line 183 def last_modified if last = get_header(LAST_MODIFIED) Time.httpdate(last) end end |
#last_modified=(utc_time) ⇒ Object
193 194 195 |
# File 'lib/action_dispatch/http/cache.rb', line 193 def last_modified=(utc_time) set_header LAST_MODIFIED, utc_time.httpdate end |
#last_modified? ⇒ Boolean
189 190 191 |
# File 'lib/action_dispatch/http/cache.rb', line 189 def last_modified? has_header? LAST_MODIFIED end |
#strong_etag=(strong_validators) ⇒ Object
237 238 239 |
# File 'lib/action_dispatch/http/cache.rb', line 237 def strong_etag=(strong_validators) set_header "ETag", generate_strong_etag(strong_validators) end |
#strong_etag? ⇒ Boolean
True if an ETag is set, and it isn't a weak validator (not preceded with
W/).
250 251 252 |
# File 'lib/action_dispatch/http/cache.rb', line 250 def strong_etag? etag? && !weak_etag? end |
#weak_etag=(weak_validators) ⇒ Object
233 234 235 |
# File 'lib/action_dispatch/http/cache.rb', line 233 def weak_etag=(weak_validators) set_header "ETag", generate_weak_etag(weak_validators) end |
#weak_etag? ⇒ Boolean
True if an ETag is set, and it's a weak validator (preceded with W/).
244 245 246 |
# File 'lib/action_dispatch/http/cache.rb', line 244 def weak_etag? etag? && etag.start_with?('W/"') end |