Method: ActionDispatch::Routing::RouteSet#extra_keys
- Defined in:
- lib/action_dispatch/routing/route_set.rb
#extra_keys(options, recall = {}) ⇒ Object
Generate the path indicated by the arguments, and return an array of the keys that were not used to generate it.
445 446 447 |
# File 'lib/action_dispatch/routing/route_set.rb', line 445 def extra_keys(, recall={}) generate_extras(, recall).last end |