Class: ActionDispatch::Routing::RoutesInspector

Inherits:
Object
  • Object
show all
Defined in:
lib/action_dispatch/routing/inspector.rb

Overview

This class is just used for displaying route information when someone executes rake routes or looks at the RoutingError page. People should not use this class.

Instance Method Summary collapse

Constructor Details

#initialize(routes) ⇒ RoutesInspector

:nodoc:



85
86
87
88
# File 'lib/action_dispatch/routing/inspector.rb', line 85

def initialize(routes)
  @engines = {}
  @routes = routes
end

Instance Method Details

#format(formatter, filter = nil) ⇒ Object



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/action_dispatch/routing/inspector.rb', line 90

def format(formatter, filter = nil)
  routes_to_display = filter_routes(filter)

  routes = collect_routes(routes_to_display)

  if routes.none?
    formatter.no_routes
    return formatter.result
  end

  formatter.header routes
  formatter.section routes

  @engines.each do |name, engine_routes|
    formatter.section_title "Routes for #{name}"
    formatter.section engine_routes
  end

  formatter.result
end