Module: ActionView::Helpers::FormOptionsHelper
- Includes:
- ERB::Util
- Included in:
- ActionView::Helpers, InstanceTag
- Defined in:
- lib/action_view/helpers/form_options_helper.rb
Overview
Provides a number of methods for turning different kinds of containers into a set of option tags.
Options
The collection_select, country_select, select, and time_zone_select methods take an options parameter, a hash.
- :include_blank - set to true or a prompt string if the first option element of the select element is a blank. Useful if there is not a default value required for the select element.
For example,
select("post", "category", Post::CATEGORIES, {:include_blank => true})
could become:
Another common case is a select tag for an belongs_to-associated object.
Example with @post.person_id => 2:
select("post", "person_id", Person.find(:all).collect {|p| [ p.name, p.id ] }, {:include_blank => 'None'})
could become:
- :prompt - set to true or a prompt string. When the select element doesn't have a value yet, this prepends an option with a generic prompt -- "Please select" -- or the given prompt string.
Example:
select("post", "person_id", Person.find(:all).collect {|p| [ p.name, p.id ] }, {:prompt => 'Select Person'})
could become:
Like the other form helpers, select can accept an :index option to manually set the ID used in the resulting output. Unlike other helpers, select expects this
option to be in the html_options parameter.
Example:
select("album[]", "genre", %w[rap rock country], {}, { :index => nil })
becomes:
Constant Summary
Constants included from ERB::Util
ERB::Util::HTML_ESCAPE, ERB::Util::JSON_ESCAPE
Instance Method Summary collapse
-
#collection_select(object, method, collection, value_method, text_method, options = {}, html_options = {}) ⇒ Object
Returns and tags for the collection of existing return values of
methodfor +object+'s class. -
#option_groups_from_collection_for_select(collection, group_method, group_label_method, option_key_method, option_value_method, selected_key = nil) ⇒ Object
Returns a string of tags, like options_from_collection_for_select, but groups them by tags based on the object relationships of the arguments.
-
#options_for_select(container, selected = nil) ⇒ Object
Accepts a container (hash, array, enumerable, your type) and returns a string of option tags.
-
#options_from_collection_for_select(collection, value_method, text_method, selected = nil) ⇒ Object
Returns a string of option tags that have been compiled by iterating over the
collectionand assigning the the result of a call to thevalue_methodas the option value and thetext_methodas the option text. -
#select(object, method, choices, options = {}, html_options = {}) ⇒ Object
Create a select tag and a series of contained option tags for the provided object and method.
-
#time_zone_options_for_select(selected = nil, priority_zones = nil, model = ::ActiveSupport::TimeZone) ⇒ Object
Returns a string of option tags for pretty much any time zone in the world.
-
#time_zone_select(object, method, priority_zones = nil, options = {}, html_options = {}) ⇒ Object
Return select and option tags for the given object and method, using #time_zone_options_for_select to generate the list of option tags.
Methods included from ERB::Util
Instance Method Details
#collection_select(object, method, collection, value_method, text_method, options = {}, html_options = {}) ⇒ Object
Returns and tags for the collection of existing return values of
method for +object+'s class. The value returned from calling method on the instance object will
be selected. If calling method returns nil, no selection is made without including :prompt
or :include_blank in the options hash.
The :value_method and :text_method parameters are methods to be called on each member
of collection. The return values are used as the value attribute and contents of each
tag, respectively.
Example object structure for use with this method:
class Post < ActiveRecord::Base
belongs_to :author
end
class Author < ActiveRecord::Base
has_many :posts
def name_with_initial
"#{first_name.first}. #{last_name}"
end
end
Sample usage (selecting the associated Author for an instance of Post, @post):
collection_select(:post, :author_id, Author.find(:all), :id, :name_with_initial, {:prompt => true})
If @post.author_id is already 1, this would return:
<select name="post[author_id]">
<option value="">Please select</option>
<option value="1" selected="selected">D. Heinemeier Hansson</option>
<option value="2">D. Thomas</option>
<option value="3">M. Clark</option>
</select>
132 133 134 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 132 def collection_select(object, method, collection, value_method, text_method, = {}, = {}) InstanceTag.new(object, method, self, .delete(:object)).to_collection_select_tag(collection, value_method, text_method, , ) end |
#option_groups_from_collection_for_select(collection, group_method, group_label_method, option_key_method, option_value_method, selected_key = nil) ⇒ Object
Returns a string of tags, like options_from_collection_for_select, but groups them by tags based on the object relationships of the arguments.
Parameters:
collection- An array of objects representing the tags.group_method- The name of a method which, when called on a member ofcollection, returns an array of child objects representing the tags.- group_label_method+ - The name of a method which, when called on a member of
collection, returns a string to be used as thelabelattribute for its tag. option_key_method- The name of a method which, when called on a child object of a member ofcollection, returns a value to be used as thevalueattribute for its tag.option_value_method- The name of a method which, when called on a child object of a member ofcollection, returns a value to be used as the contents of its tag.selected_key- A value equal to thevalueattribute for one of the tags, which will have theselectedattribute set. Corresponds to the return value of one of the calls tooption_key_method. Ifnil, no selection is made.
Example object structure for use with this method:
class Continent < ActiveRecord::Base
has_many :countries
# attribs: id, name
end
class Country < ActiveRecord::Base
belongs_to :continent
# attribs: id, name, continent_id
end
Sample usage:
option_groups_from_collection_for_select(@continents, :countries, :name, :id, :name, 3)
Possible output:
<optgroup label="Africa">
<option value="1">Egypt</option>
<option value="4">Rwanda</option>
...
</optgroup>
<optgroup label="Asia">
<option value="3" selected="selected">China</option>
<option value="12">India</option>
<option value="5">Japan</option>
...
</optgroup>
Note: Only the and tags are returned, so you still have to wrap the output in an appropriate tag.
263 264 265 266 267 268 269 270 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 263 def option_groups_from_collection_for_select(collection, group_method, group_label_method, option_key_method, option_value_method, selected_key = nil) collection.inject("") do |, group| group_label_string = eval("group.#{group_label_method}") += "<optgroup label=\"#{html_escape(group_label_string)}\">" += (eval("group.#{group_method}"), option_key_method, option_value_method, selected_key) += '</optgroup>' end end |
#options_for_select(container, selected = nil) ⇒ Object
Accepts a container (hash, array, enumerable, your type) and returns a string of option tags. Given a container
where the elements respond to first and last (such as a two-element array), the "lasts" serve as option values and
the "firsts" as option text. Hashes are turned into this form automatically, so the keys become "firsts" and values
become lasts. If selected is specified, the matching "last" or element will get the selected option-tag. selected
may also be an array of values to be selected when using a multiple select.
Examples (call, result):
([["Dollar", "$"], ["Kroner", "DKK"]])
<option value="$">Dollar</option>\n<option value="DKK">Kroner</option>
([ "VISA", "MasterCard" ], "MasterCard")
<option>VISA</option>\n<option selected="selected">MasterCard</option>
({ "Basic" => "$20", "Plus" => "$40" }, "$40")
<option value="$20">Basic</option>\n<option value="$40" selected="selected">Plus</option>
([ "VISA", "MasterCard", "Discover" ], ["VISA", "Discover"])
<option selected="selected">VISA</option>\n<option>MasterCard</option>\n<option selected="selected">Discover</option>
NOTE: Only the option tags are returned, you have to wrap this call in a regular HTML select tag.
190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 190 def (container, selected = nil) container = container.to_a if Hash === container = container.inject([]) do |, element| text, value = option_text_and_value(element) selected_attribute = ' selected="selected"' if option_value_selected?(value, selected) << %(<option value="#{html_escape(value.to_s)}"#{selected_attribute}>#{html_escape(text.to_s)}</option>) end .join("\n") end |
#options_from_collection_for_select(collection, value_method, text_method, selected = nil) ⇒ Object
Returns a string of option tags that have been compiled by iterating over the collection and assigning the
the result of a call to the value_method as the option value and the text_method as the option text.
If selected is specified, the element returning a match on value_method will get the selected option tag.
Example (call, result). Imagine a loop iterating over each person in @project.people to generate an input tag:
(@project.people, "id", "name")
<option value="#{person.id}">#{person.name}</option>
NOTE: Only the option tags are returned, you have to wrap this call in a regular HTML select tag.
211 212 213 214 215 216 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 211 def (collection, value_method, text_method, selected = nil) = collection.map do |element| [element.send(text_method), element.send(value_method)] end (, selected) end |
#select(object, method, choices, options = {}, html_options = {}) ⇒ Object
Create a select tag and a series of contained option tags for the provided object and method. The option currently held by the object will be selected, provided that the object is available. See options_for_select for the required format of the choices parameter.
Example with @post.person_id => 1:
select("post", "person_id", Person.find(:all).collect {|p| [ p.name, p.id ] }, { :include_blank => true })
could become:
This can be used to provide a default set of options in the standard way: before rendering the create form, a new model instance is assigned the default options and bound to @model_name. Usually this model is not saved to the database. Instead, a second model object is created when the create request is received. This allows the user to submit a form page more than once with the expected results of creating multiple records. In addition, this allows a single partial to be used to generate form inputs for both edit and create forms.
By default, post.person_id is the selected option. Specify :selected => value to use a different selection or :selected => nil to leave all options unselected.
98 99 100 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 98 def select(object, method, choices, = {}, = {}) InstanceTag.new(object, method, self, .delete(:object)).to_select_tag(choices, , ) end |
#time_zone_options_for_select(selected = nil, priority_zones = nil, model = ::ActiveSupport::TimeZone) ⇒ Object
Returns a string of option tags for pretty much any time zone in the
world. Supply a TimeZone name as selected to have it marked as the
selected option tag. You can also supply an array of TimeZone objects
as priority_zones, so that they will be listed above the rest of the
(long) list. (You can use TimeZone.us_zones as a convenience for
obtaining a list of the US time zones, or a Regexp to select the zones
of your choice)
The selected parameter must be either nil, or a string that names
a TimeZone.
By default, model is the TimeZone constant (which can be obtained
in Active Record as a value object). The only requirement is that the
model parameter be an object that responds to all, and returns
an array of objects that represent time zones.
NOTE: Only the option tags are returned, you have to wrap this call in a regular HTML select tag.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 290 def (selected = nil, priority_zones = nil, model = ::ActiveSupport::TimeZone) = "" zones = model.all convert_zones = lambda { |list| list.map { |z| [ z.to_s, z.name ] } } if priority_zones if priority_zones.is_a?(Regexp) priority_zones = model.all.find_all {|z| z =~ priority_zones} end += (convert_zones[priority_zones], selected) += "<option value=\"\" disabled=\"disabled\">-------------</option>\n" zones = zones.reject { |z| priority_zones.include?( z ) } end += (convert_zones[zones], selected) end |
#time_zone_select(object, method, priority_zones = nil, options = {}, html_options = {}) ⇒ Object
Return select and option tags for the given object and method, using #time_zone_options_for_select to generate the list of option tags.
In addition to the :include_blank option documented above,
this method also supports a :model option, which defaults
to TimeZone. This may be used by users to specify a different time
zone model object. (See time_zone_options_for_select for more
information.)
You can also supply an array of TimeZone objects
as priority_zones, so that they will be listed above the rest of the
(long) list. (You can use TimeZone.us_zones as a convenience for
obtaining a list of the US time zones, or a Regexp to select the zones
of your choice)
Finally, this method supports a :default option, which selects
a default TimeZone if the object's time zone is nil.
Examples:
time_zone_select( "user", "time_zone", nil, :include_blank => true)
time_zone_select( "user", "time_zone", nil, :default => "Pacific Time (US & Canada)" )
time_zone_select( "user", 'time_zone', TimeZone.us_zones, :default => "Pacific Time (US & Canada)")
time_zone_select( "user", 'time_zone', [ TimeZone['Alaska'], TimeZone['Hawaii'] ])
time_zone_select( "user", 'time_zone', /Australia/)
time_zone_select( "user", "time_zone", TZInfo::Timezone.all.sort, :model => TZInfo::Timezone)
166 167 168 |
# File 'lib/action_view/helpers/form_options_helper.rb', line 166 def time_zone_select(object, method, priority_zones = nil, = {}, = {}) InstanceTag.new(object, method, self, .delete(:object)).to_time_zone_select_tag(priority_zones, , ) end |