Module: ActionView::Helpers::JavaScriptHelper
- Included in:
- UrlHelper
- Defined in:
- lib/action_view/helpers/javascript_helper.rb
Overview
Provides functionality for working with JavaScript in your views.
Ajax, controls and visual effects
- For information on using Ajax, see ActionView::Helpers::PrototypeHelper.
- For information on using controls and visual effects, see ActionView::Helpers::ScriptaculousHelper.
Including the JavaScript libraries into your pages
Rails includes the Prototype JavaScript framework and the Scriptaculous JavaScript controls and visual effects library. If you wish to use these libraries and their helpers (ActionView::Helpers::PrototypeHelper and ActionView::Helpers::ScriptaculousHelper), you must do one of the following:
- Use <%= javascript_include_tag :defaults %> in the HEAD
section of your page (recommended): This function will return
references to the JavaScript files created by the
railscommand in your public/javascripts directory. Using it is recommended as the browser can then cache the libraries instead of fetching all the functions anew on every request. - Use <%= javascript_include_tag 'prototype' %>: As above, but will only include the Prototype core library, which means you are able to use all basic AJAX functionality. For the Scriptaculous-based JavaScript helpers, like visual effects, autocompletion, drag and drop and so on, you should use the method described above.
- Use <%= define_javascript_functions %>: this will copy all the JavaScript support functions within a single script block. Not recommended.
For documentation on javascript_include_tag see
ActionView::Helpers::AssetTagHelper.
Constant Summary collapse
- JAVASCRIPT_PATH =
File.join(File.dirname(__FILE__), 'javascripts')
Instance Method Summary collapse
-
#button_to_function(name, function, html_options = {}) ⇒ Object
Returns a link that'll trigger a JavaScript
functionusing the onclick handler. -
#define_javascript_functions ⇒ Object
Includes the Action Pack JavaScript libraries inside a single
Returns a link that'll trigger a JavaScript
functionusing the onclick handler.Examples: button_to_function "Greeting", "alert('Hello world!')" button_to_function "Delete", "if confirm('Really?'){ do_delete(); }")
67 68 69 70 71 72 73
# File 'lib/action_view/helpers/javascript_helper.rb', line 67 def (name, function, = {}) .symbolize_keys! tag(:input, .merge({ :type => "button", :value => name, :onclick => ([:onclick] ? "#{[:onclick]}; " : "") + "#{function};" })) end
#define_javascript_functions ⇒ Object
Includes the Action Pack JavaScript libraries inside a single
Escape carrier returns and single and double quotes for JavaScript segments.
101 102 103
# File 'lib/action_view/helpers/javascript_helper.rb', line 101 def escape_javascript(javascript) (javascript || '').gsub(/\r\n|\n|\r/, "\\n").gsub(/["']/) { |m| "\\#{m}" } end
#javascript_cdata_section(content) ⇒ Object
:nodoc:
111 112 113
# File 'lib/action_view/helpers/javascript_helper.rb', line 111 def javascript_cdata_section(content) #:nodoc: "\n//#{cdata_section("\n#{content}\n//")}\n" end
#javascript_tag(content) ⇒ Object
Returns a JavaScript tag with the
contentinside. Example: javascript_tag "alert('All is good')" # =>107 108 109
# File 'lib/action_view/helpers/javascript_helper.rb', line 107 def javascript_tag(content) content_tag("script", javascript_cdata_section(content), :type => "text/javascript") end
#link_to_function(name, function, html_options = {}) ⇒ Object
Returns a link that'll trigger a JavaScript
functionusing the onclick handler and return false after the fact.Examples: link_to_function "Greeting", "alert('Hello world!')" link_to_function(image_tag("delete"), "if confirm('Really?'){ do_delete(); }")
50 51 52 53 54 55 56 57 58 59
# File 'lib/action_view/helpers/javascript_helper.rb', line 50 def link_to_function(name, function, = {}) .symbolize_keys! content_tag( "a", name, .merge({ :href => [:href] || "#", :onclick => ([:onclick] ? "#{[:onclick]}; " : "") + "#{function}; return false;" }) ) end