Method: ActionView::Helpers::JavaScriptHelper#button_to_function
- Defined in:
- lib/action_view/helpers/javascript_helper.rb
#button_to_function(name, function = nil, html_options = {}) ⇒ Object
Returns a button whose onclick handler triggers the passed JavaScript.
The helper receives a name, JavaScript code, and an optional hash of HTML options. The name is used as button label and the JavaScript code goes into its onclick attribute. If html_options has an :onclick, that one is put before function.
"Greeting", "alert('Hello world!')", :class => "ok"
# => <input class="ok" onclick="alert('Hello world!');" type="button" value="Greeting" />
84 85 86 87 88 89 90 |
# File 'lib/action_view/helpers/javascript_helper.rb', line 84 def (name, function=nil, ={}) ActiveSupport::Deprecation.warn("button_to_function is deprecated and will be removed from Rails 4.0") onclick = "#{"#{[:onclick]}; " if [:onclick]}#{function};" tag(:input, .merge(:type => 'button', :value => name, :onclick => onclick)) end |