Method: ActionView::Helpers::JavaScriptHelper#button_to_function

Defined in:
lib/action_view/helpers/javascript_helper.rb

#button_to_function(name, function = nil, html_options = {}) ⇒ Object

Returns a button whose onclick handler triggers the passed JavaScript.

The helper receives a name, JavaScript code, and an optional hash of HTML options. The name is used as button label and the JavaScript code goes into its onclick attribute. If html_options has an :onclick, that one is put before function.

button_to_function "Greeting", "alert('Hello world!')", :class => "ok"
# => <input class="ok" onclick="alert('Hello world!');" type="button" value="Greeting" />


75
76
77
78
79
# File 'lib/action_view/helpers/javascript_helper.rb', line 75

def button_to_function(name, function=nil, html_options={})
  onclick = "#{"#{html_options[:onclick]}; " if html_options[:onclick]}#{function};"

  tag(:input, html_options.merge(:type => 'button', :value => name, :onclick => onclick))
end