Method: HTML::Text#find
- Defined in:
- lib/action_controller/vendor/html-scanner/html/node.rb
#find(conditions) ⇒ Object
Returns self if this node meets the given conditions. Text nodes support conditions of the following kinds:
-
if
conditionsis a string, it must be a substring of the node’s content -
if
conditionsis a regular expression, it must match the node’s content -
if
conditionsis a hash, it must contain a:contentkey that is either a string or a regexp, and which is interpreted as described above.
239 240 241 |
# File 'lib/action_controller/vendor/html-scanner/html/node.rb', line 239 def find(conditions) match(conditions) && self end |